<?php
/**
 * Oid Test
 *
 */

require("connect_config.php");
require("until.php");

echo "<pre>";

###########################################
# MAIN
###########################################

print_test_table();

$cubrid_conn = cubrid_connect(HOST_IP, HOST_PORT, DB_NAME, DB_USER, DB_PASSWORD);
if (!$cubrid_conn) {
    exit;
}

if (!prepare_table($cubrid_conn)) {
    exit;
}

$sql_stmt = "SELECT * FROM foo";
$cubrid_req = cubrid_prepare($cubrid_conn, $sql_stmt, CUBRID_INCLUDE_OID);
if (!$cubrid_req) {
    cleanup_table($cubrid_conn);
    cubrid_disconnect($cubrid_conn);
    exit;
}

$cubrid_retval = cubrid_execute($cubrid_req, CUBRID_ASYNC);
if (!$cubrid_retval) {
    cubrid_close_request($cubrid_req);
    cleanup_table($cubrid_conn);
    cubrid_disconnect($cubrid_conn);
    exit;
}

printf("\n------------ result: select * from foo --------------------\n");

cubrid_move_cursor($cubrid_req, 1, CUBRID_CURSOR_FIRST);
while ($row = cubrid_fetch($cubrid_req)) {
    $oid = cubrid_current_oid($cubrid_req);
    if (!$oid) {
	cubrid_close_request($cubrid_req);
	cleanup_table($cubrid_conn);
	cubrid_disconnect($cubrid_conn);
	exit;
    }

    printf("oid: %s ", $oid);
    printf("a: %d ", $row["a"]);

    $attr = cubrid_col_get($cubrid_conn, $oid, "b");
    printf("b: {");
    foreach ($attr as $result) {
	printf ("%s ", $result);
    }
    printf("} ");

    $attr = cubrid_col_get($cubrid_conn, $oid, "c");
    printf("c: {");
    foreach ($attr as $result) {
	printf ("%s ", $result);
    }
    printf("} ");

    printf("d: %s\n", $row["d"]);

}

printf("\n");

cubrid_move_cursor($cubrid_req, 1, CUBRID_CURSOR_FIRST);
get_test($cubrid_conn, $cubrid_req);
put_test($cubrid_conn, $cubrid_req);

cubrid_commit($cubrid_conn);
other_test($cubrid_conn, $cubrid_req);

cleanup_table($cubrid_conn);

cubrid_close_request($cubrid_req);
cubrid_disconnect($cubrid_conn);

echo "</pre>";

###########################################
# PRIVATE FUNCTION
###########################################

function get_test($cubrid_conn, $cubrid_req)
{
    while ($row = cubrid_fetch($cubrid_req)) {
	$oid = cubrid_current_oid($cubrid_req);
	if (!$oid) {
	    cubrid_close_request($cubrid_req);
	    cleanup_table($cubrid_conn);
	    cubrid_disconnect($cubrid_conn);
	    exit;
	}

	printf("col_size: b(%d) c(%d) ", 
	    cubrid_col_size($cubrid_conn, $oid, "b"), cubrid_col_size($cubrid_conn, $oid, "c"));

	printf("result: ");
	$attr = cubrid_get($cubrid_conn, $oid, array("b", "c"));
	printf("b: {");
	foreach ($attr["b"] as $value) {
	    printf("%s ", $value);
	}
	printf("} ");

	printf("c: {");
	foreach ($attr["c"] as $value) {
	    printf("%s ", $value);
	}
	printf("}\n");
    }

    cubrid_move_cursor($cubrid_req, 1, CUBRID_CURSOR_FIRST);
    while (list($id) = cubrid_fetch($cubrid_req)) {
	$oid = cubrid_current_oid($cubrid_req);
	if (!$oid) {
	    printf("--- LINE: %d ERR_CODE: %d ERR_MSG: %s\n", __LINE__, cubrid_error_code(), cubrid_error_msg());
	    cubrid_close_request($cubrid_req);
	    cleanup_table($cubrid_conn);
	    cubrid_disconnect($cubrid_conn);
	    exit;
	}

	$attr = cubrid_get($cubrid_conn, $oid, "b");
	printf ("id: %d is_instance: %d ", $id, cubrid_is_instance($cubrid_conn, $oid));
	printf("oid: %s class_name: %s ", $oid, cubrid_get_class_name($cubrid_conn, $oid));
	printf ("b: %s\n", $attr);
    }

    cubrid_commit($cubrid_conn);
}

function put_test($cubrid_conn, $cubrid_req)
{
    printf("\n------------ cubrid_put: set foo(a) to value(8) --------------------\n");

    cubrid_move_cursor($cubrid_req, 1, CUBRID_CURSOR_FIRST);
    while (list($id) = cubrid_fetch($cubrid_req)) {
	$oid = cubrid_current_oid($cubrid_req);
	if (!$oid) {
	    cubrid_close_request($cubrid_req);
	    cleanup_table($cubrid_conn);
	    cubrid_disconnect($cubrid_conn);
	    exit;
	}

	$attr = cubrid_get($cubrid_conn, $oid, array("a"));
	$attr["a"] = "8";
	cubrid_put($cubrid_conn, $oid, $attr);
    }

    cubrid_commit($cubrid_conn);
    print_foo($cubrid_conn);

    printf("\n------------ cubrid_put: set foo(b) to value({2, 4, 8}) --------------------\n");

    cubrid_move_cursor($cubrid_req, 1, CUBRID_CURSOR_FIRST);
    while (list($id) = cubrid_fetch($cubrid_req)) {
	$oid = cubrid_current_oid($cubrid_req);
	if (!$oid) {
	    cubrid_close_request($cubrid_req);
	    cleanup_table($cubrid_conn);
	    cubrid_disconnect($cubrid_conn);
	    exit;
	}

	cubrid_put($cubrid_conn, $oid, "b", array(2, 4, 8));
    }

    cubrid_commit($cubrid_conn);
    print_foo($cubrid_conn);

    printf("\n------------ cubrid_put: set foo(a,b,c,d) to value(69, {1,3,5}, {2,4,8}, \"test\") --------------------\n");

    cubrid_move_cursor($cubrid_req, 1, CUBRID_CURSOR_FIRST);
    while (list($id) = cubrid_fetch($cubrid_req)) {
	$oid = cubrid_current_oid($cubrid_req);
	if (!$oid) {
	    cubrid_close_request($cubrid_req);
	    cleanup_table($cubrid_conn);
	    cubrid_disconnect($cubrid_conn);
	    exit;
	}

	cubrid_put($cubrid_conn, $oid, array("a" => 69, "b" => array(1, 3, 5), "c" => array(2, 4, 8), "d" => "test"));
    }

    cubrid_commit($cubrid_conn);
    print_foo($cubrid_conn);
}

function other_test($cubrid_conn, $cubrid_req)
{
    cubrid_move_cursor($cubrid_req, 1, CUBRID_CURSOR_FIRST);
    while (list($id) = cubrid_fetch($cubrid_req)) {
	$oid = cubrid_current_oid($cubrid_req);

	cubrid_lock_read($cubrid_conn, $oid);
	cubrid_lock_write($cubrid_conn, $oid);

	if (!$oid) {
	    cubrid_close_request($cubrid_req);
	    cleanup_table($cubrid_conn);
	    cubrid_disconnect($cubrid_conn);
	    exit;
	}

	cubrid_drop($cubrid_conn, $oid);
    }
    
    cubrid_commit($cubrid_conn);
    cubrid_rollback($cubrid_conn);
}

?>
