<?php
/**
 * Query Test
 *
 */

require("connect_config.php");
require("until.php");

echo "<pre>";

###########################################
# MAIN
###########################################

get_php_version_info();

$cubrid_conn = cubrid_connect(HOST_IP, HOST_PORT, DB_NAME);
if (!$cubrid_conn) {
    echo "Error Code: ", cubrid_error_code ();
    echo "Error Facility: ", cubrid_error_code_facility ();
    echo "Error Message: ", cubrid_error_msg ();
    exit;
}

get_cubrid_version_info($cubrid_conn);
get_db_server_info($cubrid_conn);
get_db_param($cubrid_conn);

$sql_stmt = "SELECT * FROM game WHERE host_year = ? AND nation_code = ? AND medal = 'G'";

$cubrid_req = cubrid_prepare($cubrid_conn, $sql_stmt);
if (!$cubrid_req) {
    echo "Error Code: ", cubrid_error_code ();
    echo "Error Facility: ", cubrid_error_code_facility ();
    echo "Error Message: ", cubrid_error_msg ();

    cubrid_disconnect($cubrid_conn);
    exit;
}

$cubrid_retval = cubrid_bind($cubrid_req, 1, 2004, "int");
if (!$cubrid_retval) {
    echo "Error Code: ", cubrid_error_code ();
    echo "Error Facility: ", cubrid_error_code_facility ();
    echo "Error Message: ", cubrid_error_msg ();


    cubrid_close_request($cubrid_req);
    cubrid_disconnect($cubrid_conn);
    exit;
}

$cubrid_retval = cubrid_bind($cubrid_req, 2, "AUS");
if (!$cubrid_retval) {
    echo "Error Code: ", cubrid_error_code ();
    echo "Error Facility: ", cubrid_error_code_facility ();
    echo "Error Message: ", cubrid_error_msg ();

    cubrid_close_request($cubrid_req);
    cubrid_disconnect($cubrid_conn);
    exit;
}
 
$cubrid_retval = cubrid_execute($cubrid_req);
if (!$cubrid_retval) {
    echo "Error Code: ", cubrid_error_code ();
    echo "Error Facility: ", cubrid_error_code_facility ();
    echo "Error Message: ", cubrid_error_msg ();

    cubrid_close_request($cubrid_req);
    cubrid_disconnect($cubrid_conn);
    exit;
}

get_result_info($cubrid_req);
print_field_info($cubrid_req, 1);

move_cursor_test($cubrid_conn);
get_result_length($cubrid_req);
fetch_object_test($cubrid_req);
fetch_assoc_test($cubrid_req);

printf("quer_result[last_row][last_col]: %s\n", 
    cubrid_result($cubrid_req, cubrid_num_rows($cubrid_req) - 1, cubrid_num_cols($cubrid_req) - 1));

cubrid_free_result($cubrid_req);
cubrid_close_request($cubrid_req);
cubrid_commit($cubrid_conn);
cubrid_disconnect($cubrid_conn);

echo "</pre>";

###########################################
# PRIVATE FUNCTION
###########################################

function get_php_version_info()
{
    printf("\n------------ get_php_version_info --------------------\n");

    printf("%-30s %s\n", "PHP Version:", phpversion());
    printf("%-30s %s\n", "CUBRID PHP API Version:", cubrid_version());

    printf("\n\n");
}

function get_cubrid_version_info($conn_handle)
{
    printf("\n------------ get_cubrid_version_info --------------------\n");

    $server_version = cubrid_get_server_info($conn_handle);
    if (!$server_version) {
	echo "Error Code: ", cubrid_error_code ();
	echo "Error Facility: ", cubrid_error_code_facility ();
	echo "Error Message: ", cubrid_error_msg ();

	return false;
    }

    $client_version = cubrid_get_client_info();
    if (!$client_version) {
	echo "Error Code: ", cubrid_error_code ();
	echo "Error Facility: ", cubrid_error_code_facility ();
	echo "Error Message: ", cubrid_error_msg ();

	return false;
    }

    printf("%-30s %s\n", "Server Version:", $server_version);
    printf("%-30s %s\n", "Client Version:", $client_version);

    printf("\n\n");

    return true;
}

function get_db_server_info($conn_handle)
{
    printf("\n------------ get_db_server_info --------------------\n");

    $charset = cubrid_get_charset($conn_handle);
    if (!$charset) {
	echo "Error Code: ", cubrid_error_code ();
	echo "Error Facility: ", cubrid_error_code_facility ();
	echo "Error Message: ", cubrid_error_msg ();

	return false;
    }

    /* return index array */
    $db_list = cubrid_list_dbs($conn_handle);
    if (!$db_list) {
	echo "Error Code: ", cubrid_error_code ();
	echo "Error Facility: ", cubrid_error_code_facility ();
	echo "Error Message: ", cubrid_error_msg ();

	return false;
    }

    printf("%-30s %s\n", "CUBRID Charset:", $charset);
    printf("%-30s", "DB List:");
    foreach ($db_list as $db_name) {
	printf(" %s", $db_name);
    }
    printf("\n\n\n");

    return true;
}

function get_db_param($conn_handle)
{
    printf("------------ get_db_param --------------------\n");

    /* return assoc array */
    $param_list = cubrid_get_db_parameter($conn_handle);
    if (!$param_list) {
	echo "Error Code: ", cubrid_error_code ();
	echo "Error Facility: ", cubrid_error_code_facility ();
	echo "Error Message: ", cubrid_error_msg ();

	return false;
    }

    while (list($param_name, $param_value) = each($param_list)) {
	printf("%-30s %s\n", $param_name, $param_value);
    }
    printf("\n\n");

    return true;
}

function move_cursor_test($conn_handle)
{
    $req_handle = cubrid_execute($conn_handle, "SELECT * FROM code");

    printf("\n------------ SELECT * FROM code --------------------\n");

    cubrid_move_cursor($req_handle, 1, CUBRID_CURSOR_FIRST);
    print_result($req_handle);

    printf("\n------------ the last 2 in code --------------------\n");

    cubrid_move_cursor($req_handle, 5, CUBRID_CURSOR_FIRST);
    print_result($req_handle);

    printf("\n------------ the last in code --------------------\n");

    cubrid_move_cursor($req_handle, 1, CUBRID_CURSOR_LAST);
    print_result($req_handle);

    cubrid_free_result($req_handle);
    cubrid_close_request($req_handle);
}

function get_result_length($req_handle)
{
    printf("\n------------ last 5 result length info --------------------\n");

    cubrid_move_cursor($req_handle, 5, CUBRID_CURSOR_LAST);
    while ($row = cubrid_fetch_row($req_handle)) {
	if (!$row) {
	    echo "Error Code: ", cubrid_error_code ();
	    echo "Error Facility: ", cubrid_error_code_facility ();
	    echo "Error Message: ", cubrid_error_msg ();

	    exit;
	}

	$col_num = count($row);
	for ($i = 0; $i < $col_num; $i++) {
	    printf("%s ", $row[$i]);
	}
	printf("| ");

	$len_list = cubrid_fetch_lengths($req_handle);
	$col_num = count($len_list);
	for ($i = 0; $i < $col_num; $i++) {
	    printf("%d ", $len_list[$i]);
	}
	printf("\n");
    }
    printf("\n");
}

function fetch_object_test($req_handle)
{
    printf("\n------------ cubrid_fetch_object: the last --------------------\n");

    cubrid_move_cursor($req_handle, 1, CUBRID_CURSOR_LAST);
    $row = cubrid_fetch_object($req_handle);
    print_r($row);
    printf("\n");
}

function fetch_assoc_test($req_handle)
{
    printf("\n------------ cubrid_fetch_assoc: the last --------------------\n");

    cubrid_data_seek($req_handle, cubrid_num_rows($req_handle) - 1);
    $row = cubrid_fetch_assoc($req_handle);
    print_r($row);
    printf("\n");
}

?>
