<?php
/**
 * Untility functions
 *
 */

function print_test_table()
{
    printf("\n--------- create tables for test ------------------\n");

    printf("CREATE TABLE foo(a int AUTO_INCREMENT, b set(int), c list(int), d char(10));\n");
    printf("INSERT INTO foo(a, b, c, d) VALUES(1, {1,2,3}, {11,22,33,333}, 'a');\n");
    printf("INSERT INTO foo(a, b, c, d) VALUES(2, {4,5,6}, {44,55,66,666}, 'b');\n");

    printf("\n");

    printf("CREATE TABLE bar(e int);\n");
    printf("ALTER TABLE bar ADD SUPERCLASS foo;\n");

    printf("\n");
}

function print_type_test_table()
{
    printf("\n--------- create tables for type test ------------------\n");

    printf("CREATE TABLE baz(\n\tcolumn_integer INTEGER, \n\tcolumn_smallint SMALLINT, \n\tcolumn_numeric_9_2 NUMERIC(9,2), \n\tcolumn_char_9 CHAR(9), \n\tcolumn_varchar_92 VARCHAR(92), \n\tcolumn_date DATE, \n\tcolumn_bit BIT(4), \n\tcolumn_time TIME, \n\tcolumn_timestamp TIMESTAMP, \n\tcolumn_set SET(int), \n\tPRIMARY KEY (column_integer)\n);\n");

    printf("\n");

    printf("INSERT INTO baz VALUES(1, 11, 1.1, '1', CURRENT_USER, SYS_DATE, B'1', SYS_TIME, SYS_TIMESTAMP, NULL);\n");
    printf("INSERT INTO baz VALUES(22, 222, 2.2, '22', CURRENT_USER, SYS_DATE, B'10', SYS_TIME, SYS_TIMESTAMP, {1});\n");
    printf("INSERT INTO baz VALUES(333, 3333, 3.3, '333', 'dba', '10/31/2008', B'1010', '12:00:00 AM', '13:15:45 10/31/2008', {1,2});\n");

    printf("\n");
}

function prepare_table($conn_handle)
{
    $retval = check_table_existence($conn_handle, "person");
    if($retval == -1) {
	return false;
    } elseif ($retval == 0) {
	$req_handle = cubrid_execute($conn_handle, "CREATE TABLE person(name char(20), image object)");
	if (!$req_handle) {
	    return false;
	}

	cubrid_close_request($req_handle);
    }

    $sql_create_foo = "CREATE TABLE foo(a int AUTO_INCREMENT, b set(int), c list(int), d char(10))";

    $retval = check_table_existence($conn_handle, "foo");
    if($retval == -1) {
	return false;
    } elseif ($retval == 0) {
	$req_handle = cubrid_execute($conn_handle, $sql_create_foo);
	if (!$req_handle) {
	    return false;
	}

	cubrid_execute($conn_handle, 
	    "INSERT INTO foo(a, b, c, d) VALUES(1, {1,2,3}, {11,22,33,333}, 'a')", 
	    CUBRID_ASYNC);
	cubrid_execute($conn_handle, 
	    "INSERT INTO foo(a, b, c, d) VALUES(2, {4,5,6}, {44,55,66,666}, 'b')", 
	    CUBRID_ASYNC);
	
	cubrid_close_request($req_handle);
    }

    $sql_create_bar = "CREATE TABLE bar(e int)";

    $retval = check_table_existence($conn_handle, "bar");
    if($retval == -1) {
	return false;
    } elseif ($retval == 0) {
	$req_handle = cubrid_execute($conn_handle, $sql_create_bar);
	if (!$req_handle) {
	    return false;
	}
	cubrid_close_request($req_handle);

	$req_handle = cubrid_execute($conn_handle, "ALTER TABLE bar ADD SUPERCLASS foo");
	if (!$req_handle) {
	    return false;
	}
	cubrid_close_request($req_handle);
    }

    $sql_create_baz = "CREATE TABLE baz(
		    column_integer INTEGER, 
		    column_smallint SMALLINT, 
		    column_numeric_9_2 NUMERIC(9,2), 
		    column_char_9 CHAR(9), 
		    column_varchar_92 VARCHAR(92), 
		    column_date DATE, 
		    column_bit BIT(4), 
		    column_time TIME, 
		    column_timestamp TIMESTAMP, 
		    column_set SET(int), 
		    PRIMARY KEY (column_integer)
		)";

    $retval = check_table_existence($conn_handle, "baz");
    if($retval == -1) {
	return false;
    } elseif ($retval == 0) {
	$req_handle = cubrid_execute($conn_handle, $sql_create_baz);
	if (!$req_handle) {
	    return false;
	}

	cubrid_execute($conn_handle, 
	    "INSERT INTO baz VALUES(1, 11, 1.1, '1', CURRENT_USER, SYS_DATE, B'1', SYS_TIME, SYS_TIMESTAMP, NULL)", 
	    CUBRID_ASYNC);
	cubrid_execute($conn_handle, 
	    "INSERT INTO baz VALUES(22, 222, 2.2, '22', CURRENT_USER, SYS_DATE, B'10', SYS_TIME, SYS_TIMESTAMP, {1})", 
	    CUBRID_ASYNC);
	cubrid_execute($conn_handle, 
	    "INSERT INTO baz VALUES(333, 3333, 3.3, '333', 'dba', '10/31/2008', B'1010', '12:00:00 AM', '13:15:45 10/31/2008', {1,2})", 
	    CUBRID_ASYNC);
	
	cubrid_close_request($req_handle);
    }

    cubrid_commit($conn_handle);

    return true;
}

function cleanup_table($conn_handle)
{
    $retval = check_table_existence($conn_handle, "person");
    if($retval == -1) {
	return false;
    } elseif ($retval == 1) {
	$req_handle = cubrid_execute($conn_handle, "DROP TABLE person");
	if (!$req_handle) {
	    return false;
	}

	cubrid_close_request($req_handle);
    }

    $retval = check_table_existence($conn_handle, "foo");
    if($retval == -1) {
	return false;
    } elseif ($retval == 1) {
	$req_handle = cubrid_execute($conn_handle, "DROP TABLE foo");
	if (!$req_handle) {
	    return false;
	}

	cubrid_close_request($req_handle);
    }

    $retval = check_table_existence($conn_handle, "bar");
    if($retval == -1) {
	return false;
    } elseif ($retval == 1) {
	$req_handle = cubrid_execute($conn_handle, "DROP TABLE bar");
	if (!$req_handle) {
	    return false;
	}
	cubrid_close_request($req_handle);
    }

    $retval = check_table_existence($conn_handle, "baz");
    if($retval == -1) {
	return false;
    } elseif ($retval == 1) {
	$req_handle = cubrid_execute($conn_handle, "DROP TABLE baz");
	if (!$req_handle) {
	    return false;
	}
	cubrid_close_request($req_handle);
    }

    cubrid_commit($conn_handle);

    return true;
}

function check_table_existence($conn_handle, $table_name)
{
    $sql_stmt = "SELECT class_name FROM db_class WHERE class_name = ?";
    $cubrid_req = cubrid_prepare($conn_handle, $sql_stmt);
    if (!$cubrid_req) {
	return -1;
    }

    $cubrid_retval = cubrid_bind($cubrid_req, 1, $table_name);
    if (!$cubrid_req) {
	cubrid_close_request($cubrid_req);
	return -1;
    }
     
    $cubrid_retval = cubrid_execute($cubrid_req);
    if (!$cubrid_retval) {
	cubrid_close_request($cubrid_req);
	return -1;
    }

    $row_num = cubrid_num_rows($cubrid_req);
    if ($row_num < 0) {
	cubrid_close_request($cubrid_req);
	return -1;
    }
    
    cubrid_close_request($cubrid_req);

    if ($row_num > 0) {
	return 1;
    } else {
	return 0;
    }
} 

function print_foo($conn_handle)
{
    $req_handle = cubrid_execute($conn_handle, "select * from foo", CUBRID_INCLUDE_OID);
    if (!$req_handle) {
	return false;
    }
    
    cubrid_move_cursor($req_handle, 1, CUBRID_CURSOR_FIRST);
    while ($row = cubrid_fetch($req_handle)) {
	$oid = cubrid_current_oid($req_handle);
	if (!$oid) {
	    cubrid_close_request($req_handle);
	    return false;
	}

	printf("a: %d ", $row["a"]);

	$attr = cubrid_col_get($conn_handle, $oid, "b");
	printf("b: {");
	foreach ($attr as $result) {
	    printf ("%s ", $result);
	}
	printf("} ");

	$attr = cubrid_col_get($conn_handle, $oid, "c");
	printf("c: {");
	foreach ($attr as $result) {
	    printf ("%s ", $result);
	}
	printf("} ");

	printf("d: %s\n", $row["d"]);
    }
    print("\n");
}

function print_field_info($req_handle, $offset = 0)
{
    printf("\n------------ print_field_info --------------------\n");

    cubrid_field_seek($req_handle, $offset);

    $field = cubrid_fetch_field($req_handle, $offset);
    if (!$field) {
	return false;
    }

    printf("%-30s %s\n", "name:", $field->name);
    printf("%-30s %s\n", "table:", $field->table);
    printf("%-30s \"%s\"\n", "default value:", $field->def);
    printf("%-30s %d\n", "max lenght:", $field->max_length);
    printf("%-30s %d\n", "not null:", $field->not_null);
    printf("%-30s %d\n", "unique key:", $field->unique_key);
    printf("%-30s %d\n", "multiple key:", $field->multiple_key);
    printf("%-30s %d\n", "numeric:", $field->numeric);

    return true;
}

function print_result($req_handle)
{
    $j = 1;
    while ($row = cubrid_fetch_row($req_handle)) {
	if (!$row) {
	    return false;
	}

	$col_num = count($row);
	printf("%-2d - ", $j);
	for ($i = 0; $i < $col_num; $i++) {
	    printf("%s ", $row[$i]);
	}
	printf("\n");
	$j++;
    }
    
    return true;
}

function print_result_type($req_handle, $type = CUBRID_BOTH)
{
    printf("\n------------ print_result_type --------------------\n");

    $row_num = cubrid_num_rows($req_handle);
    if ($row_num < 0) {
	return false;
    }

    $col_num = cubrid_num_cols($req_handle);
    if ($col_num < 0) {
	return false;
    }

    $column_name_list = cubrid_column_names($req_handle);
    if (!$column_name_list) {
	return false;
    }

    while ($row = cubrid_fetch($req_handle, $type)) {
	switch ($type) {
	case CUBRID_OBJECT:
	    foreach ($column_name_list as $column_name) {
		printf("%s ", $row->$column_name);
	    } 

	    break;
	case CUBRID_NUM:
	    for ($i = 0; $i < $col_num; $i++) {
		printf("%s ", $row[$i]);
	    }

	    break;
	case CUBRID_ASSOC:
	    foreach ($column_name_list as $column_name) {
		printf("%s ", $row[$column_name]);
	    }

	    break;
	case CUBRID_BOTH:
	    for ($i = 0; $i < $col_num; $i++) {
		printf("%s ", $row[$i]);
	    }

	    break;
	default:
	    break;
	}
	printf("\n");
    }

    printf("\n\n");

    return true;
}

function get_result_info($req_handle)
{
    printf("\n------------ get_result_info --------------------\n");

    $row_num = cubrid_num_rows($req_handle);
    if ($row_num < 0) {
	return false;
    }

    $col_num = cubrid_num_cols($req_handle);
    if ($col_num < 0) {
	return false;
    }

    $field_num = cubrid_num_fields($req_handle);
    if ($col_num < 0) {
	return false;
    }
    assert($field_num == $col_num);

    $column_name_list = cubrid_column_names($req_handle);
    if (!$column_name_list) {
	return false;
    }

    $column_type_list = cubrid_column_types($req_handle);
    if (!$column_type_list) {
	return false;
    }

    $column_last_name = cubrid_field_name($req_handle, $col_num - 1);
    if ($column_last_name < 0) {
	return false;
    }

    $column_last_table = cubrid_field_table($req_handle, $col_num - 1);
    if ($column_last_table < 0) {
	return false;
    }

    $column_last_type = cubrid_field_type($req_handle, $col_num - 1);
    if ($column_last_type < 0) {
	return false;
    }

    $column_last_len = cubrid_field_len($req_handle, $col_num - 1);
    if (!$column_last_len) {
	return false;
    }

    $column_1_flags = cubrid_field_flags($req_handle, 1);
    if ($column_1_flags < 0) {
	return false;
    }

    printf("%-30s %d\n", "Row count:", $row_num);
    printf("%-30s %d\n", "Column count:", $col_num);
    printf("\n");

    printf("%-30s %-30s %-15s\n", "Column Names", "Column Types", "Column Len");
    printf("------------------------------------------------------------------------------\n");
    $size = count($column_name_list);
    for($i = 0; $i < $size; $i++) {
	$column_len = cubrid_field_len($req_handle, $i);
	printf("%-30s %-30s %-15s\n", $column_name_list[$i], $column_type_list[$i], $column_len); 
    }
    printf("\n\n");

    printf("%-30s %s\n", "Last Column Name:", $column_last_name);
    printf("%-30s %s\n", "Last Column Table:", $column_last_table);
    printf("%-30s %s\n", "Last Column Type:", $column_last_type);
    printf("%-30s %d\n", "Last Column Len:", $column_last_len);
    printf("%-30s %s\n", "Second Column Flags:", $column_1_flags);

    printf("\n\n");

    return true;
}

?>
